/* This file is part of dengue: Dengue fever individual propagation model
Copyright (C) 2012 Harish Padmanabha, Fabio Correa

This project has been developed by Harish Padmanabha<harishpadmanabha@gmail.com> and Fabio Correa<facorread@gmail.com>
This code has been delivered to the Public Library of Science, on February 16, 2015.
We, the developers, grant you a license to review and modify this source code for your own use.
We do not grant you license to distribute or publish this program or any derivative work, any of its output, the ideas or algorithms contained within, in any form.
Anybody who wishes to get a copy of this source code or to get this project under a different license should email the developers directly.

*/

/// \file eta.cpp Implementation of the calculation of the Estimated Time to Arrival or completion of a program.

//Check for C++0x
#if (__cplusplus <= 199711L) && !defined(__GXX_EXPERIMENTAL_CXX0X__)
#error This source code requires c++0x; it has been tested with GCC-4.4.4 and later.
#endif


/// \def _wur_
/// \brief Warns about unused results of functions
/// \details _wur_ can be used in most function declarations so that the compiler warns about unused results of these functions. _wur_ is automatically enabled on GCC only; in other compilers it should do nothing.
#if defined(__GXX_EXPERIMENTAL_CXX0X__)
#define _wur_ __attribute__ (( warn_unused_result ))
#else
#define _wur_
#endif

#include <iostream>
#include "eta.h"

using std::cerr;
using std::endl;

void etaCls::start(const int nScenarios) {
	mNScenarios = nScenarios;
	mStartingTime = boost::posix_time::second_clock::local_time();
	mScenario = 0;
}

void etaCls::step() {
	using namespace boost::posix_time;
	auto diffTime(second_clock::local_time() - mStartingTime);
	time_duration estimatedDiff(diffTime * mNScenarios / ++mScenario);
	mDuration = estimatedDiff - diffTime;
	mCompletedPercent = 100 * mScenario / mNScenarios;
	mEstimatedTime = mStartingTime + estimatedDiff;
}

void etaCls::info() const {
	cerr << " " << mCompletedPercent << "%";
	if(mScenario > 10) {
		if(mDuration.total_seconds() < 600)
			cerr << " ETA " << mDuration.minutes() << " m " << mDuration.seconds() << " s" << endl;
		else
			cerr << " ETA " << mEstimatedTime << endl;
	} else
		cerr << endl;
}
