/* This file is part of dengue: Dengue fever individual propagation model
Copyright (C) 2012 Harish Padmanabha, Fabio Correa

This project has been developed by Harish Padmanabha<harishpadmanabha@gmail.com> and Fabio Correa<facorread@gmail.com>
This code has been delivered to the Public Library of Science, on February 16, 2015.
We, the developers, grant you a license to review and modify this source code for your own use.
We do not grant you license to distribute or publish this program or any derivative work, any of its output, the ideas or algorithms contained within, in any form.
Anybody who wishes to get a copy of this source code or to get this project under a different license should email the developers directly.

*/

/// \file param.cpp Implementation of classes that represent simulation parameters and simulation time.

#include "param.h"

/// Steps the clock one day. \returns whether this is the last evolution step.
void intervalClockCls::init(size_t lastDay, size_t intervalsPerDay) {
	dayClockCls::init(lastDay);
	mIntervalsPerDay = intervalsPerDay;
	mInvInterval = 1.0 / static_cast<double>(intervalsPerDay);
}

bool intervalClockCls::simStep() {
	if(++mInterval % mIntervalsPerDay) {
		if(mIsANewDay)
			mIsANewDay = false;
		return mDay == mLastDay;
	}
	++mDay;
	mIsANewDay = true;
	return false;
}

void paramIdCls::printHeading(std::ofstream& outfile) const {
	outfile << "\t" << this->heading;
}

void boolRangeCls::printHeading(std::ofstream& outfile, const bool prependTab) const {
	if(prependTab)
		outfile << "\t";
	outfile << this->heading;
}

void boolRangeCls::printDescription() const {
	descrfile << this->heading << "\t" << this->descr << "\t\t\t\t\tFalse(0), True(1)\n";
}
